covariance subpackage
=====================

Submodules
----------

estimator module
----------------

.. automodule:: skrmt.covariance.estimator
   :members:
   :undoc-members:
   :show-inheritance:

metrics module
--------------

.. automodule:: skrmt.covariance.metrics
   :members:
   :undoc-members:
   :show-inheritance: